@@ -1,5 +1,5 @@
-from database_types.idatabase import IDatabase
-from column import Column
+from sql-faker.database_types.idatabase import IDatabase
+from sql-faker.column import Column
 
 
 class PrimaryKey(Column):
